@@ -28,7 +28,9 @@ type SourceState struct {
 	ignore                  *patternSet
 	interpreters            map[string]*Interpreter
 	minVersion              semver.Version
+	mode                    Mode
 	defaultTemplateDataFunc func() map[string]interface{}
+	readTemplateData        bool
 	userTemplateData        map[string]interface{}
 	priorityTemplateData    map[string]interface{}
 	templateData            map[string]interface{}
@@ -61,6 +63,13 @@ func WithInterpreters(interpreters map[string]*Interpreter) SourceStateOption {
 	}
 }
 
+// WithMode sets the mode.
+func WithMode(mode Mode) SourceStateOption {
+	return func(s *SourceState) {
+		s.mode = mode
+	}
+}
+
 // WithPriorityTemplateData adds priority template data.
 func WithPriorityTemplateData(priorityTemplateData map[string]interface{}) SourceStateOption {
 	return func(s *SourceState) {
@@ -68,6 +77,13 @@ func WithPriorityTemplateData(priorityTemplateData map[string]interface{}) Sourc
 	}
 }
 
+// WithReadTemplateData sets whether to read .chezmoidata.<format> files.
+func WithReadTemplateData(readTemplateData bool) SourceStateOption {
+	return func(s *SourceState) {
+		s.readTemplateData = readTemplateData
+	}
+}
+
 // WithSourceDir sets the source directory.
 func WithSourceDir(sourceDirAbsPath AbsPath) SourceStateOption {
 	return func(s *SourceState) {
@@ -114,6 +130,7 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		umask:                Umask,
 		encryption:           NoEncryption{},
 		ignore:               newPatternSet(),
+		readTemplateData:     true,
 		priorityTemplateData: make(map[string]interface{}),
 		userTemplateData:     make(map[string]interface{}),
 		templateOptions:      DefaultTemplateOptions,
@@ -158,7 +175,7 @@ func (s *SourceState) Add(sourceSystem System, persistentState PersistentState,
 		return destAbsPaths[i] < destAbsPaths[j]
 	})
 
-	updates := make([]update, 0, len(destAbsPathInfos))
+	sourceUpdates := make([]update, 0, len(destAbsPathInfos))
 	newSourceStateEntries := make(map[SourceRelPath]SourceStateEntry)
 	newSourceStateEntriesByTargetRelPath := make(map[RelPath]SourceStateEntry)
 DESTABSPATH:
@@ -237,12 +254,12 @@ DESTABSPATH:
 		newSourceStateEntries[sourceEntryRelPath] = newSourceStateEntry
 		newSourceStateEntriesByTargetRelPath[targetRelPath] = newSourceStateEntry
 
-		updates = append(updates, update)
+		sourceUpdates = append(sourceUpdates, update)
 	}
 
-	entries := make(map[RelPath]SourceStateEntry)
+	sourceEntries := make(map[RelPath]SourceStateEntry)
 	for sourceRelPath, sourceStateEntry := range newSourceStateEntries {
-		entries[sourceRelPath.RelPath()] = sourceStateEntry
+		sourceEntries[sourceRelPath.RelPath()] = sourceStateEntry
 	}
 
 	// Simulate removing a directory by creating SourceStateRemove entries for
@@ -257,7 +274,7 @@ DESTABSPATH:
 				continue
 			}
 			sourceRelPath := sourceStateEntry.SourceRelPath()
-			entries[sourceRelPath.RelPath()] = &SourceStateRemove{}
+			sourceEntries[sourceRelPath.RelPath()] = &SourceStateRemove{}
 			update := update{
 				destAbsPath: s.destDirAbsPath.Join(targetRelPath),
 				entryState: &EntryState{
@@ -265,16 +282,16 @@ DESTABSPATH:
 				},
 				sourceRelPaths: []SourceRelPath{sourceRelPath},
 			}
-			updates = append(updates, update)
+			sourceUpdates = append(sourceUpdates, update)
 		}
 	}
 
 	targetSourceState := &SourceState{
-		entries: entries,
+		entries: sourceEntries,
 	}
 
-	for _, update := range updates {
-		for _, sourceRelPath := range update.sourceRelPaths {
+	for _, sourceUpdate := range sourceUpdates {
+		for _, sourceRelPath := range sourceUpdate.sourceRelPaths {
 			if err := targetSourceState.Apply(sourceSystem, sourceSystem, NullPersistentState{}, s.sourceDirAbsPath, sourceRelPath.RelPath(), ApplyOptions{
 				Include: options.Include,
 				Umask:   s.umask,
@@ -282,7 +299,7 @@ DESTABSPATH:
 				return err
 			}
 		}
-		if err := persistentStateSet(persistentState, EntryStateBucket, []byte(update.destAbsPath), update.entryState); err != nil {
+		if err := persistentStateSet(persistentState, EntryStateBucket, []byte(sourceUpdate.destAbsPath), sourceUpdate.entryState); err != nil {
 			return err
 		}
 	}
@@ -579,6 +596,9 @@ func (s *SourceState) Read() error {
 		}
 		switch {
 		case strings.HasPrefix(info.Name(), dataName):
+			if !s.readTemplateData {
+				return nil
+			}
 			return s.addTemplateData(sourceAbsPath)
 		case info.Name() == ignoreName:
 			// .chezmoiignore is interpreted as a template. we walk the
@@ -948,6 +968,19 @@ func (s *SourceState) newCreateTargetStateEntryFunc(fileAttr FileAttr, sourceLaz
 // file with sourceLazyContents.
 func (s *SourceState) newFileTargetStateEntryFunc(sourceRelPath SourceRelPath, fileAttr FileAttr, sourceLazyContents *lazyContents) targetStateEntryFunc {
 	return func(destSystem System, destAbsPath AbsPath) (TargetStateEntry, error) {
+		if s.mode == ModeSymlink && !fileAttr.Encrypted && !fileAttr.Executable && !fileAttr.Private && !fileAttr.Template {
+			switch contents, err := sourceLazyContents.Contents(); {
+			case err != nil:
+				return nil, err
+			case isEmpty(contents) && !fileAttr.Empty:
+				return &TargetStateRemove{}, nil
+			default:
+				linkname := normalizeLinkname(string(s.sourceDirAbsPath.Join(sourceRelPath.RelPath())))
+				return &TargetStateSymlink{
+					lazyLinkname: newLazyLinkname(linkname),
+				}, nil
+			}
+		}
 		contentsFunc := func() ([]byte, error) {
 			contents, err := sourceLazyContents.Contents()
 			if err != nil {
@@ -1075,7 +1108,8 @@ func (s *SourceState) newSymlinkTargetStateEntryFunc(sourceRelPath SourceRelPath
 					return "", err
 				}
 			}
-			return string(bytes.TrimSpace(linknameBytes)), nil
+			linkname := normalizeLinkname(string(bytes.TrimSpace(linknameBytes)))
+			return linkname, nil
 		}
 		return &TargetStateSymlink{
 			lazyLinkname: newLazyLinknameFunc(linknameFunc),
