@@ -103,7 +103,7 @@ func (c *Config) defaultPreAddFunc(targetRelPath chezmoi.RelPath, newSourceState
 
 func (c *Config) runAddCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
 	destAbsPathInfos, err := c.destAbsPathInfos(sourceState, args, destAbsPathInfosOptions{
-		follow:    c.Add.follow,
+		follow:    c.Mode == chezmoi.ModeSymlink || c.Add.follow,
 		recursive: c.Add.recursive,
 	})
 	if err != nil {
