@@ -56,6 +56,7 @@ type Config struct {
 	Data             map[string]interface{}          `mapstructure:"data"`
 	DestDirAbsPath   chezmoi.AbsPath                 `mapstructure:"destDir"`
 	Interpreters     map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
+	Mode             chezmoi.Mode                    `mapstructure:"mode"`
 	Pager            string                          `mapstructure:"pager"`
 	Remove           bool                            `mapstructure:"remove"`
 	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
@@ -64,6 +65,7 @@ type Config struct {
 	UseBuiltinGit    autoBool                        `mapstructure:"useBuiltinGit"`
 
 	// Global configuration, not settable in the config file.
+	configFormat  readDataFormat
 	cpuProfile    chezmoi.AbsPath
 	debug         bool
 	dryRun        bool
@@ -256,6 +258,10 @@ func newConfig(options ...configOption) (*Config, error) {
 			recursive: true,
 		},
 		Diff: diffCmdConfig{
+			Args: []string{
+				"{{ .Destination }}",
+				"{{ .Target }}",
+			},
 			Exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 		},
@@ -291,11 +297,11 @@ func newConfig(options ...configOption) (*Config, error) {
 			recursive: true,
 		},
 		data: dataCmdConfig{
-			format: defaultDataFormat,
+			format: defaultWriteDataFormat,
 		},
 		dump: dumpCmdConfig{
 			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
-			format:    defaultDataFormat,
+			format:    defaultWriteDataFormat,
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
 			recursive: true,
 		},
@@ -322,10 +328,10 @@ func newConfig(options ...configOption) (*Config, error) {
 		},
 		state: stateCmdConfig{
 			data: stateDataCmdConfig{
-				format: defaultDataFormat,
+				format: defaultWriteDataFormat,
 			},
 			dump: stateDumpCmdConfig{
-				format: defaultDataFormat,
+				format: defaultWriteDataFormat,
 			},
 		},
 		status: statusCmdConfig{
@@ -428,7 +434,7 @@ type applyArgsOptions struct {
 }
 
 func (c *Config) applyArgs(targetSystem chezmoi.System, targetDirAbsPath chezmoi.AbsPath, args []string, options applyArgsOptions) error {
-	sourceState, err := c.sourceState()
+	sourceState, err := c.newSourceState()
 	if err != nil {
 		return err
 	}
@@ -969,7 +975,7 @@ func (c *Config) gitAutoPush(status *git.Status) error {
 
 func (c *Config) makeRunEWithSourceState(runE func(*cobra.Command, []string, *chezmoi.SourceState) error) func(*cobra.Command, []string) error {
 	return func(cmd *cobra.Command, args []string) error {
-		sourceState, err := c.sourceState()
+		sourceState, err := c.newSourceState()
 		if err != nil {
 			return err
 		}
@@ -977,12 +983,12 @@ func (c *Config) makeRunEWithSourceState(runE func(*cobra.Command, []string, *ch
 	}
 }
 
-func (c *Config) marshal(dataFormat dataFormat, data interface{}) error {
+func (c *Config) marshal(dataFormat writeDataFormat, data interface{}) error {
 	var format chezmoi.Format
 	switch dataFormat {
-	case dataFormatJSON:
+	case writeDataFormatJSON:
 		format = chezmoi.JSONFormat
-	case dataFormatYAML:
+	case writeDataFormatYAML:
 		format = chezmoi.YAMLFormat
 	default:
 		return fmt.Errorf("%s: unknown format", dataFormat)
@@ -1011,10 +1017,12 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
 	persistentFlags.BoolVar(&c.Remove, "remove", c.Remove, "Remove entries from destination directory")
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
+	persistentFlags.Var(&c.Mode, "mode", "Mode")
 	persistentFlags.Var(&c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
 	for _, key := range []string{
 		"color",
 		"destination",
+		"mode",
 		"remove",
 		"source",
 	} {
@@ -1024,6 +1032,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	}
 
 	persistentFlags.VarP(&c.configFileAbsPath, "config", "c", "Set config file")
+	persistentFlags.Var(&c.configFormat, "config-format", "Set config file format")
 	persistentFlags.Var(&c.cpuProfile, "cpu-profile", "Write a CPU profile to path")
 	persistentFlags.BoolVar(&c.debug, "debug", c.debug, "Include debug information in output")
 	persistentFlags.BoolVarP(&c.dryRun, "dry-run", "n", c.dryRun, "Do not make any modifications to the destination directory")
@@ -1095,6 +1104,31 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	return rootCmd, nil
 }
 
+func (c *Config) newSourceState(options ...chezmoi.SourceStateOption) (*chezmoi.SourceState, error) {
+	s := chezmoi.NewSourceState(append([]chezmoi.SourceStateOption{
+		chezmoi.WithDefaultTemplateDataFunc(c.defaultTemplateData),
+		chezmoi.WithDestDir(c.DestDirAbsPath),
+		chezmoi.WithEncryption(c.encryption),
+		chezmoi.WithInterpreters(c.Interpreters),
+		chezmoi.WithMode(c.Mode),
+		chezmoi.WithPriorityTemplateData(c.Data),
+		chezmoi.WithSourceDir(c.SourceDirAbsPath),
+		chezmoi.WithSystem(c.sourceSystem),
+		chezmoi.WithTemplateFuncs(c.templateFuncs),
+		chezmoi.WithTemplateOptions(c.Template.Options),
+	}, options...)...)
+
+	if err := s.Read(); err != nil {
+		return nil, err
+	}
+
+	if minVersion := s.MinVersion(); c.version != nil && !isDevVersion(c.version) && c.version.LessThan(minVersion) {
+		return nil, fmt.Errorf("source state requires version %s or later, chezmoi is version %s", minVersion, c.version)
+	}
+
+	return s, nil
+}
+
 func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error {
 	defer pprof.StopCPUProfile()
 
@@ -1372,6 +1406,9 @@ func (c *Config) promptChoice(prompt string, choices []string) (string, error) {
 func (c *Config) readConfig() error {
 	v := viper.New()
 	v.SetConfigFile(string(c.configFileAbsPath))
+	if c.configFormat != "" {
+		v.SetConfigType(c.configFormat.String())
+	}
 	v.SetFs(afero.FromIOFS{FS: c.fileSystem})
 	switch err := v.ReadInConfig(); {
 	case errors.Is(err, fs.ErrNotExist):
@@ -1435,30 +1472,6 @@ func (c *Config) sourceAbsPaths(sourceState *chezmoi.SourceState, args []string)
 	return sourceAbsPaths, nil
 }
 
-func (c *Config) sourceState() (*chezmoi.SourceState, error) {
-	s := chezmoi.NewSourceState(
-		chezmoi.WithDefaultTemplateDataFunc(c.defaultTemplateData),
-		chezmoi.WithDestDir(c.DestDirAbsPath),
-		chezmoi.WithEncryption(c.encryption),
-		chezmoi.WithInterpreters(c.Interpreters),
-		chezmoi.WithPriorityTemplateData(c.Data),
-		chezmoi.WithSourceDir(c.SourceDirAbsPath),
-		chezmoi.WithSystem(c.sourceSystem),
-		chezmoi.WithTemplateFuncs(c.templateFuncs),
-		chezmoi.WithTemplateOptions(c.Template.Options),
-	)
-
-	if err := s.Read(); err != nil {
-		return nil, err
-	}
-
-	if minVersion := s.MinVersion(); c.version != nil && !isDevVersion(c.version) && c.version.LessThan(minVersion) {
-		return nil, fmt.Errorf("source state requires version %s or later, chezmoi is version %s", minVersion, c.version)
-	}
-
-	return s, nil
-}
-
 type targetRelPathsOptions struct {
 	mustBeInSourceState bool
 	recursive           bool
